## Cryptocurrencies.AI API python client

Almost zero-dependency client: add https://pypi.org/project/six/ to requirements

Just copy ccai/client.py into your project and you are ready to go

More examples coming soon!